/// <reference types="node" />
import * as errors from './errors';
export declare const Errors: typeof errors;
export declare enum Type {
    TYPE_ILP_PREPARE = 12,
    TYPE_ILP_FULFILL = 13,
    TYPE_ILP_REJECT = 14
}
export interface IlpErrorClass {
    message: string;
    ilpErrorCode?: string;
    ilpErrorData?: Buffer;
}
export declare const deserializeEnvelope: (binary: Buffer) => {
    type: number;
    contents: Buffer;
};
export declare type IlpPacket = {
    type: Type.TYPE_ILP_PREPARE;
    typeString?: 'ilp_prepare';
    data: IlpPrepare;
} | {
    type: Type.TYPE_ILP_FULFILL;
    typeString?: 'ilp_fulfill';
    data: IlpFulfill;
} | {
    type: Type.TYPE_ILP_REJECT;
    typeString?: 'ilp_reject';
    data: IlpReject;
};
export interface IlpPrepare {
    amount: string;
    executionCondition: Buffer;
    expiresAt: Date;
    destination: string;
    data: Buffer;
}
export declare const serializeIlpPrepare: (json: IlpPrepare) => Buffer;
export declare const deserializeIlpPrepare: (binary: Buffer) => IlpPrepare;
export interface IlpFulfill {
    fulfillment: Buffer;
    data: Buffer;
}
export declare function isPrepare(packet: IlpAny): packet is IlpPrepare;
export declare function isFulfill(packet: IlpAny): packet is IlpFulfill;
export declare function isReject(packet: IlpAny): packet is IlpReject;
export declare const serializeIlpFulfill: (json: IlpFulfill) => Buffer;
export declare const deserializeIlpFulfill: (binary: Buffer) => IlpFulfill;
export interface IlpReject {
    code: string;
    triggeredBy: string;
    message: string;
    data: Buffer;
}
export declare const serializeIlpReject: (json: IlpReject) => Buffer;
export declare const deserializeIlpReject: (binary: Buffer) => IlpReject;
export declare const serializeIlpPacket: (obj: IlpPacket) => Buffer;
export declare const deserializeIlpPacket: (binary: Buffer) => IlpPacket;
export declare type IlpPacketHander = (packet: IlpPrepare) => Promise<IlpReply>;
export declare type IlpAny = IlpPrepare | IlpFulfill | IlpReject;
export declare type IlpReply = IlpFulfill | IlpReject;
export declare function deserializeIlpReply(data: Buffer): IlpReply;
export declare function serializeIlpReply(packet: IlpReply): Buffer;
export declare const errorToReject: (address: string, error: IlpErrorClass) => Buffer;
export declare const errorToIlpReject: (address: string, error: IlpErrorClass) => IlpReject;
